@@ -8,7 +8,8 @@ class GroupLoss(SimilarityLoss):
     """Base class for Group losses.
 
     Args:
-        distance_metric_name: Name of the distance function, e.g., :class:`~quaterion.distances.Distance`.
+        distance_metric_name: Name of the distance function, e.g.,
+            :class:`~quaterion.distances.Distance`.
     """
 
     def __init__(self, distance_metric_name: Distance = Distance.COSINE):
